Struct TcpStream

struct TcpStream { ... }

A non-blocking TCP stream between a local socket and a remote socket.

The socket will be closed when the value is dropped.

Examples

# use std::net::{TcpListener, SocketAddr};
# use std::error::Error;
#
# fn main() -> Result<(), Box<dyn Error>> {
let address: SocketAddr = "127.0.0.1:0".parse()?;
let listener = TcpListener::bind(address)?;
use mio::{Events, Interest, Poll, Token};
use mio::net::TcpStream;
use std::time::Duration;

let mut stream = TcpStream::connect(listener.local_addr()?)?;

let mut poll = Poll::new()?;
let mut events = Events::with_capacity(128);

// Register the socket with `Poll`
poll.registry().register(&mut stream, Token(0), Interest::WRITABLE)?;

poll.poll(&mut events, Some(Duration::from_millis(100)))?;

// The socket might be ready at this point
#     Ok(())
# }

Implementations

impl TcpStream

fn connect(addr: SocketAddr) -> Result<TcpStream>

Create a new TCP stream and issue a non-blocking connect to the specified address.

Notes

The returned TcpStream may not be connected (and thus usable), unlike the API found in std::net::TcpStream. Because Mio issues a non-blocking connect it will not block the thread and instead return an unconnected TcpStream.

Ensuring the returned stream is connected is surprisingly complex when considering cross-platform support. Doing this properly should follow the steps below, an example implementation can be found here.

  1. Call TcpStream::connect
  2. Register the returned stream with at least write interest.
  3. Wait for a (writable) event.
  4. Check TcpStream::take_error. If it returns an error, then something went wrong. If it returns Ok(None), then proceed to step 5.
  5. Check TcpStream::peer_addr. If it returns libc::EINPROGRESS or ErrorKind::NotConnected it means the stream is not yet connected, go back to step 3. If it returns an address it means the stream is connected, go to step 6. If another error is returned something went wrong.
  6. Now the stream can be used.

This may return a WouldBlock in which case the socket connection cannot be completed immediately, it usually means there are insufficient entries in the routing cache.

fn from_std(stream: TcpStream) -> TcpStream

Creates a new TcpStream from a standard net::TcpStream.

This function is intended to be used to wrap a TCP stream from the standard library in the Mio equivalent. The conversion assumes nothing about the underlying stream; it is left up to the user to set it in non-blocking mode.

Note

The TCP stream here will not have connect called on it, so it should already be connected via some other means (be it manually, or the standard library).

fn peer_addr(self: &Self) -> Result<SocketAddr>

Returns the socket address of the remote peer of this TCP connection.

fn local_addr(self: &Self) -> Result<SocketAddr>

Returns the socket address of the local half of this TCP connection.

fn shutdown(self: &Self, how: Shutdown) -> Result<()>

Shuts down the read, write, or both halves of this connection.

This function will cause all pending and future I/O on the specified portions to return immediately with an appropriate value (see the documentation of Shutdown).

fn set_nodelay(self: &Self, nodelay: bool) -> Result<()>

Sets the value of the TCP_NODELAY option on this socket.

If set, this option disables the Nagle algorithm. This means that segments are always sent as soon as possible, even if there is only a small amount of data. When not set, data is buffered until there is a sufficient amount to send out, thereby avoiding the frequent sending of small packets.

Notes

On Windows make sure the stream is connected before calling this method, by receiving an (writable) event. Trying to set nodelay on an unconnected TcpStream is unspecified behavior.

fn nodelay(self: &Self) -> Result<bool>

Gets the value of the TCP_NODELAY option on this socket.

For more information about this option, see set_nodelay.

Notes

On Windows make sure the stream is connected before calling this method, by receiving an (writable) event. Trying to get nodelay on an unconnected TcpStream is unspecified behavior.

fn set_ttl(self: &Self, ttl: u32) -> Result<()>

Sets the value for the IP_TTL option on this socket.

This value sets the time-to-live field that is used in every packet sent from this socket.

Notes

On Windows make sure the stream is connected before calling this method, by receiving an (writable) event. Trying to set ttl on an unconnected TcpStream is unspecified behavior.

fn ttl(self: &Self) -> Result<u32>

Gets the value of the IP_TTL option for this socket.

For more information about this option, see set_ttl.

Notes

On Windows make sure the stream is connected before calling this method, by receiving an (writable) event. Trying to get ttl on an unconnected TcpStream is unspecified behavior.

fn take_error(self: &Self) -> Result<Option<Error>>

Get the value of the SO_ERROR option on this socket.

This will retrieve the stored error in the underlying socket, clearing the field in the process. This can be useful for checking errors between calls.

fn peek(self: &Self, buf: &mut [u8]) -> Result<usize>

Receives data on the socket from the remote address to which it is connected, without removing that data from the queue. On success, returns the number of bytes peeked.

Successive calls return the same data. This is accomplished by passing MSG_PEEK as a flag to the underlying recv system call.

fn try_io<F, T>(self: &Self, f: F) -> Result<T>
where
    F: FnOnce() -> Result<T>

Execute an I/O operation ensuring that the socket receives more events if it hits a WouldBlock error.

Notes

This method is required to be called for all I/O operations to ensure the user will receive events once the socket is ready again after returning a WouldBlock error.

Examples

# use std::error::Error;
#
# fn main() -> Result<(), Box<dyn Error>> {
use std::io;
#[cfg(any(unix, target_os = "wasi"))]
use std::os::fd::AsRawFd;
#[cfg(windows)]
use std::os::windows::io::AsRawSocket;
use mio::net::TcpStream;

let address = "127.0.0.1:8080".parse().unwrap();
let stream = TcpStream::connect(address)?;

// Wait until the stream is readable...

// Read from the stream using a direct libc call, of course the
// `io::Read` implementation would be easier to use.
let mut buf = [0; 512];
let n = stream.try_io(|| {
    let buf_ptr = &mut buf as *mut _ as *mut _;
    #[cfg(unix)]
    let res = unsafe { libc::recv(stream.as_raw_fd(), buf_ptr, buf.len(), 0) };
    #[cfg(windows)]
    let res = unsafe { libc::recvfrom(stream.as_raw_socket() as usize, buf_ptr, buf.len() as i32, 0, std::ptr::null_mut(), std::ptr::null_mut()) };
    if res != -1 {
        Ok(res as usize)
    } else {
        // If EAGAIN or EWOULDBLOCK is set by libc::recv, the closure
        // should return `WouldBlock` error.
        Err(io::Error::last_os_error())
    }
})?;
eprintln!("read {} bytes", n);
# Ok(())
# }

impl AsFd for TcpStream

fn as_fd(self: &Self) -> BorrowedFd<'_>

impl AsRawFd for TcpStream

fn as_raw_fd(self: &Self) -> RawFd

impl Debug for TcpStream

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for TcpStream

impl From for TcpStream

fn from(fd: OwnedFd) -> Self

Converts a RawFd to a TcpStream.

Notes

The caller is responsible for ensuring that the socket is in non-blocking mode.

impl FromRawFd for TcpStream

unsafe fn from_raw_fd(fd: RawFd) -> TcpStream

Converts a RawFd to a TcpStream.

Notes

The caller is responsible for ensuring that the socket is in non-blocking mode.

impl IntoRawFd for TcpStream

fn into_raw_fd(self: Self) -> RawFd

impl Read for TcpStream

fn read(self: &mut Self, buf: &mut [u8]) -> Result<usize>
fn read_vectored(self: &mut Self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>

impl RefUnwindSafe for TcpStream

impl Send for TcpStream

impl Source for TcpStream

fn register(self: &mut Self, registry: &Registry, token: Token, interests: Interest) -> Result<()>
fn reregister(self: &mut Self, registry: &Registry, token: Token, interests: Interest) -> Result<()>
fn deregister(self: &mut Self, registry: &Registry) -> Result<()>

impl Sync for TcpStream

impl Unpin for TcpStream

impl UnsafeUnpin for TcpStream

impl UnwindSafe for TcpStream

impl Write for TcpStream

fn write(self: &mut Self, buf: &[u8]) -> Result<usize>
fn write_vectored(self: &mut Self, bufs: &[IoSlice<'_>]) -> Result<usize>
fn flush(self: &mut Self) -> Result<()>

impl<T> Any for TcpStream

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TcpStream

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TcpStream

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for TcpStream

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for TcpStream

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TcpStream

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TcpStream

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>